wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_workspace_response_200_tasks_item_status_type_7 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_workspace_response_200_tasks_item_status_type_7

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5T = TypeVar("T", bound="V1TaskGetByWorkspaceResponse200TasksItemStatusType7")
     6
     7@attr.s(auto_attribs=True)
     8class V1TaskGetByWorkspaceResponse200TasksItemStatusType7:
     9    """
    10    Attributes:
    11        other (str):
    12    """
    13
    14    other: str
    15    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    16
    17
    18    def to_dict(self) -> Dict[str, Any]:
    19        other = self.other
    20
    21        field_dict: Dict[str, Any] = {}
    22        field_dict.update(self.additional_properties)
    23        field_dict.update({
    24            "Other": other,
    25        })
    26
    27        return field_dict
    28
    29
    30
    31    @classmethod
    32    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    33        d = src_dict.copy()
    34        other = d.pop("Other")
    35
    36        v1_task_get_by_workspace_response_200_tasks_item_status_type_7 = cls(
    37            other=other,
    38        )
    39
    40        v1_task_get_by_workspace_response_200_tasks_item_status_type_7.additional_properties = d
    41        return v1_task_get_by_workspace_response_200_tasks_item_status_type_7
    42
    43    @property
    44    def additional_keys(self) -> List[str]:
    45        return list(self.additional_properties.keys())
    46
    47    def __getitem__(self, key: str) -> Any:
    48        return self.additional_properties[key]
    49
    50    def __setitem__(self, key: str, value: Any) -> None:
    51        self.additional_properties[key] = value
    52
    53    def __delitem__(self, key: str) -> None:
    54        del self.additional_properties[key]
    55
    56    def __contains__(self, key: str) -> bool:
    57        return key in self.additional_properties

@attr.s(auto_attribs=True)
class V1TaskGetByWorkspaceResponse200TasksItemStatusType7: View Source

     8@attr.s(auto_attribs=True)
     9class V1TaskGetByWorkspaceResponse200TasksItemStatusType7:
    10    """
    11    Attributes:
    12        other (str):
    13    """
    14
    15    other: str
    16    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    17
    18
    19    def to_dict(self) -> Dict[str, Any]:
    20        other = self.other
    21
    22        field_dict: Dict[str, Any] = {}
    23        field_dict.update(self.additional_properties)
    24        field_dict.update({
    25            "Other": other,
    26        })
    27
    28        return field_dict
    29
    30
    31
    32    @classmethod
    33    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    34        d = src_dict.copy()
    35        other = d.pop("Other")
    36
    37        v1_task_get_by_workspace_response_200_tasks_item_status_type_7 = cls(
    38            other=other,
    39        )
    40
    41        v1_task_get_by_workspace_response_200_tasks_item_status_type_7.additional_properties = d
    42        return v1_task_get_by_workspace_response_200_tasks_item_status_type_7
    43
    44    @property
    45    def additional_keys(self) -> List[str]:
    46        return list(self.additional_properties.keys())
    47
    48    def __getitem__(self, key: str) -> Any:
    49        return self.additional_properties[key]
    50
    51    def __setitem__(self, key: str, value: Any) -> None:
    52        self.additional_properties[key] = value
    53
    54    def __delitem__(self, key: str) -> None:
    55        del self.additional_properties[key]
    56
    57    def __contains__(self, key: str) -> bool:
    58        return key in self.additional_properties

Attributes: other (str):

V1TaskGetByWorkspaceResponse200TasksItemStatusType7(other: str) View Source

    2def __init__(self, other):
    3    self.other = other
    4    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class V1TaskGetByWorkspaceResponse200TasksItemStatusType7.

def to_dict(self) -> Dict[str, Any]: View Source

    19    def to_dict(self) -> Dict[str, Any]:
    20        other = self.other
    21
    22        field_dict: Dict[str, Any] = {}
    23        field_dict.update(self.additional_properties)
    24        field_dict.update({
    25            "Other": other,
    26        })
    27
    28        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    32    @classmethod
    33    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    34        d = src_dict.copy()
    35        other = d.pop("Other")
    36
    37        v1_task_get_by_workspace_response_200_tasks_item_status_type_7 = cls(
    38            other=other,
    39        )
    40
    41        v1_task_get_by_workspace_response_200_tasks_item_status_type_7.additional_properties = d
    42        return v1_task_get_by_workspace_response_200_tasks_item_status_type_7

additional_keys: List[str]